@@ -12,7 +12,7 @@ identical = lambda val: partial(op.is_, val)
 boolean = lambda x: isinstance(x, bool)
 number = lambda x: isinstance(x, numbers.Number)
 pos = lambda x: True if number(x) and x > 0 else False
-string = lambda x: isinstance(x, str)
+string = lambda x: isinstance(x, basestring)
 match = lambda pattern: lambda text: re.search(pattern, text)
 subset = lambda set_: partial(op.contains, set_)
 any = lambda x: x
